import React, { useMemo, useState, useEffect } from 'react'
import { Button, DatePicker, Modal } from 'antd'
import PageTable from '@/components/PageTable'
import { getAccountLogList, generateAccountLog } from '@/services/account'

export default (props) => {

  const [visible, setVisible] = useState(false)
  const [tradeDate, setTradeDate] = useState()

  const columns = [
    {
      title: '交易日期',
      dataIndex: 'createDate',
      key: 'createDate',
      search: false
    },
    {
      title: '交易日',
      dataIndex: 'dailyId',
      key: 'dailyId',
      renderFormItem: (item, fProps, form) => {
        return <DatePicker />
      },
      hideInTable: true,
    },
    {
      title: '订单号',
      dataIndex: 'orderNo',
      key: 'orderNo',
      search: true,
    },
    {
      title: '交易类型',
      dataIndex: 'chargeType',
      key: 'chargeType',
      search: false,
      render: t => t == -1 ? '退费' : '-'
    },
    {
      title: '金额/元',
      dataIndex: 'charges',
      key: 'charges',
      search: false,
      render: t => Number(t / 100).toFixed(2)
    },
    {
      title: '手续费/元',
      dataIndex: 'poundage',
      key: 'poundage',
      search: false,
      render: t => Number(t / 100).toFixed(2)
    },
  ]

  const handleOk = () => {
    const theDay = tradeDate.format('YYYY-MM-DD')
    generateAccountLog(theDay)
    setTradeDate()
    setVisible(false)
  }

  const handleCancel = () => {
    setVisible(false)
    setTradeDate()
  }

  const actions = useMemo(() => ([
    <Button key="primary" type="primary" onClick={() => setVisible(true)}>
      拉取账单
    </Button>,
  ]), [])

  return (
    <div>
      <PageTable
        toolbar={{ actions }}
        columns={columns}
        params={{ monthId: props.monthId }}
        request={getAccountLogList}
        options={false}
        rowKey="serialNo"
      />
      <Modal title="交易日" visible={visible} onOk={handleOk} onCancel={handleCancel}>
        <DatePicker onChange={val => setTradeDate(val)} style={{ width: '240px' }} />
      </Modal>
    </div>
  )
}
