import React, { useMemo, useState } from 'react'
import moment from 'moment'
import { Button, DatePicker, Modal, message } from 'antd'
import PageTable from '@/components/PageTable'
import { getAccountMonthList, createMonthInfo, updateMonthInfo } from '@/services/account'

const { confirm } = Modal;

export default (props) => {

  const [visible, setVisible] = useState(false)
  const [tradeDate, setTradeDate] = useState()

  const handleEdit = row => {
    if (row.status === 1) {
      message.warning('当前月份已对账');
    }

    confirm({
      title: '确认对账',
      content: '当前操作不可逆, 请确认金额无误',
      onOk() {
        updateMonthInfo({ ...row, status: 1 }).then(() => {
          message.success('操作成功')
        })
      },
    });    
  }

  const handleDetail = row => {
    props.onSwitch(row.monthId)
  }

  const columns = [
    {
      title: '月份',
      dataIndex: 'monthId',
      key: 'monthId',
      renderFormItem: (item, fProps, form) => {
        return <DatePicker picker="month" />
      },
    },
    {
      title: '金额/元',
      dataIndex: 'totalCharge',
      key: 'totalCharge',
      search: false,
      render: t => Number(t / 100).toFixed(2)
    },
    {
      title: '金额/元',
      dataIndex: 'totalCharge',
      key: 'totalCharge',
      search: false,
      render: t => Number(t / 100).toFixed(2)
    },
    {
      title: '状态',
      dataIndex: 'status',
      key: 'status',
      search: false,
      render: t => t == 1 ? '已结' : '-'
    },
    {
      title: '操作',
      key: 'option',
      width: 120,
      valueType: 'option',
      render: (_, row, index, action) => [
        row.status != 1 && 
        <a
          key="a"
          onClick={() => handleEdit(row)}
        >
          对账
        </a>,
        <a
          key="b"
          onClick={() => handleDetail(row)}
        >
          详情
        </a>,
      ].filter(Boolean),
    },
  ]

  const handleOk = () => {
    const theMonth = tradeDate.format('YYYY-MM')
    createMonthInfo(theMonth)
    setTradeDate()
    setVisible(false)
  }

  const handleCancel = () => {
    setVisible(false)
    setTradeDate()
  }

  const actions = useMemo(() => ([
    <Button key="primary" type="primary" onClick={() => setVisible(true)}>
      生成账单
    </Button>,
  ]), [])

  return (
    <div>
      <PageTable
        toolbar={{ actions }}
        columns={columns}
        request={getAccountMonthList}
        options={false}
        beforeSearchSubmit={x => ({ ...x, monthId: x.monthId ? moment(x.monthId).format('YYYY-MM') : undefined })}
        rowKey="monthId"
      />
      <Modal title="对账月份" visible={visible} onOk={handleOk} onCancel={handleCancel}>
        <DatePicker picker="month" onChange={val => setTradeDate(val)} style={{ width: '240px' }} />
      </Modal>
    </div>
  )
}
